pub struct SlotDiffView {
pub slot_index: u32,
pub item_id: u32,
pub bonus_id_hash: u32,
}Expand description
A single slot override that distinguishes a permutation from baseline.
Fields
slot_index: u32item_id: u32bonus_id_hash: u32Trait Implementations
Sourceimpl Clone for SlotDiffView
impl Clone for SlotDiffView
Sourcefn clone(&self) -> SlotDiffView
fn clone(&self) -> SlotDiffView
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlotDiffView
impl Debug for SlotDiffView
Sourceimpl Serialize for SlotDiffView
impl Serialize for SlotDiffView
Sourceimpl Tsify for SlotDiffView
impl Tsify for SlotDiffView
const DECL: &'static str = "/**\n * A single slot override that distinguishes a permutation from baseline.\n */\nexport interface SlotDiffView {\n slot_index: number;\n item_id: number;\n bonus_id_hash: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,